@@ -1,4 +1,4 @@
-from pyckson.const import get_cls_attr, has_cls_attr, PYCKSON_RULE_ATTR
+from pyckson.const import get_cls_attr, has_cls_attr, PYCKSON_RULE_ATTR, PYCKSON_ENUM_OPTIONS
 
 global_defaults = []
 
@@ -19,5 +19,14 @@ def reset_defaults():
 def apply_defaults(cls):
     global global_defaults
     for default in global_defaults:
-        if not has_cls_attr(cls, get_cls_attr(default, PYCKSON_RULE_ATTR)):
+        default_attr = get_cls_attr(default, PYCKSON_RULE_ATTR)
+        if default_attr != PYCKSON_ENUM_OPTIONS and not has_cls_attr(cls, default_attr):
+            default(cls)
+
+
+def apply_enum_default(cls):
+    global global_defaults
+    for default in global_defaults:
+        default_attr = get_cls_attr(default, PYCKSON_RULE_ATTR)
+        if default_attr == PYCKSON_ENUM_OPTIONS and not has_cls_attr(cls, default_attr):
             default(cls)
