@@ -4,7 +4,7 @@ from typing import Tuple, Union
 def inspect_optional_typing(annotation) -> Tuple[bool, type]:
     # seems like at some point internal behavior on typing Union changed
     # https://bugs.launchpad.net/ubuntu/+source/python3.5/+bug/1650202
-    if "Union" not in str(annotation):
+    if "Union" not in str(annotation) and "Optional" not in str(annotation):
         return False, type(None)
 
     if hasattr(annotation, '__origin__'):
